Tile class

Represents a single tile in the archive.

Constructors

Tile(int id, {List<int>? bytes, Exception? exception, Compression compression = Compression.unknown, TileType type = TileType.unknown})

Properties

compression Compression
final
hashCode int
The hash code for this object.
no setterinherited
id int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type TileType
final

Methods

bytes() List<int>
The tile's uncompressed bytes. This may throw an Exception if there was an issue reading or decompressing the bytes.
compressedBytes() List<int>
The tile's bytes compressed with the compression algorithm. This may be useful if the Tile is going to be served with the same compression as how they are stored in the archive. This may throw an Exception if there was an issue reading the bytes for any reason.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited